@@ -33,21 +33,17 @@ describe R10K::Module::Forge do
 
   describe "implementing the Puppetfile spec" do
     it "should implement 'branan/eight_hundred', '8.0.0'" do
-      expect(described_class).to be_implement('branan/eight_hundred', { version: '8.0.0' })
+      expect(described_class).to be_implement('branan/eight_hundred', { type: 'forge', version: '8.0.0' })
     end
 
     it "should implement 'branan-eight_hundred', '8.0.0'" do
-      expect(described_class).to be_implement('branan-eight_hundred', { version: '8.0.0' })
-    end
-
-    it "should fail with an invalid title" do
-      expect(described_class).to_not be_implement('branan!eight_hundred', { version: '8.0.0' })
+      expect(described_class).to be_implement('branan-eight_hundred', { type: 'forge', version: '8.0.0' })
     end
   end
 
   describe "implementing the standard options interface" do
     it "should implement {type: forge}" do
-      expect(described_class).to be_implement('branan-eight_hundred', {type: 'forge', version: '8.0.0', source: 'not implemented'})
+      expect(described_class).to be_implement('branan-eight_hundred', { type: 'forge', version: '8.0.0', source: 'not implemented' })
     end
   end
 
@@ -71,6 +67,12 @@ describe R10K::Module::Forge do
     end
   end
 
+  describe "invalid attributes" do
+    it "errors on invalid versions" do
+      expect { described_class.new('branan/eight_hundred', '/moduledir', { version: '_8.0.0_' }) }.to raise_error ArgumentError, /version/
+    end
+  end
+
   describe "properties" do
     subject { described_class.new('branan/eight_hundred', fixture_modulepath, { version: '8.0.0' }) }
 
